==> SingularityViewer-v1.7.0.tar.gz: SingularityViewer-v1.7.0/indra/newview/lluploadfloaterobservers.h <==
/**
 * @file lluploadfloaterobservers.h
 * @brief LLUploadModelPremissionsResponder declaration
 *
 * $LicenseInfo:firstyear=2011&license=viewergpl$
 * 
 * Copyright (c) 2011, Linden Research, Inc.
 * 
 * Second Life Viewer Source Code
 * The source code in this file ("Source Code") is provided by Linden Lab
 * to you under the terms of the GNU General Public License, version 2.0
 * ("GPL"), unless you have obtained a separate licensing agreement
 * ("Other License"), formally executed by you and Linden Lab.  Terms of
 * the GPL can be found in doc/GPL-license.txt in this distribution, or
 * online at http://secondlifegrid.net/programs/open_source/licensing/gplv2
 * 
 * There are special exceptions to the terms and conditions of the GPL as
 * it is applied to this Source Code. View the full text of the exception
 * in the file doc/FLOSS-exception.txt in this software distribution, or
 * online at
 * http://secondlifegrid.net/programs/open_source/licensing/flossexception
 * 
 * By copying, modifying or distributing this software, you acknowledge
 * that you have read and understood your obligations described above,
 * and agree to abide by those obligations.
 * 
 * ALL LINDEN LAB SOURCE CODE IS PROVIDED "AS IS." LINDEN LAB MAKES NO
 * WARRANTIES, EXPRESS, IMPLIED OR OTHERWISE, REGARDING ITS ACCURACY,
 * COMPLETENESS OR PERFORMANCE.
 * $/LicenseInfo$
 */

#ifndef LL_LLUPLOADFLOATEROBSERVERS_H
#define LL_LLUPLOADFLOATEROBSERVERS_H

#include "llfloater.h"
#include "llhttpclient.h"
#include "llui.h"

class LLUploadPermissionsObserver
{
public:

	LLUploadPermissionsObserver() { mUploadPermObserverHandle.bind(this); }
	virtual ~LLUploadPermissionsObserver() {}

	virtual void onPermissionsReceived(const LLSD& result) = 0;
	virtual void setPermissonsErrorStatus(U32 status, const std::string& reason) = 0;

	LLHandle<LLUploadPermissionsObserver> getPermObserverHandle() const
	{
		return mUploadPermObserverHandle;
	}

protected:
	LLRootHandle<LLUploadPermissionsObserver> mUploadPermObserverHandle;
};

class LLWholeModelFeeObserver
{
public:
	LLWholeModelFeeObserver() { mWholeModelFeeObserverHandle.bind(this); }
	virtual ~LLWholeModelFeeObserver() {}

	virtual void onModelPhysicsFeeReceived(const LLSD& result, std::string upload_url) = 0;
	virtual void setModelPhysicsFeeErrorStatus(U32 status, const std::string& reason) = 0;

	LLHandle<LLWholeModelFeeObserver> getWholeModelFeeObserverHandle() const
	{
		return mWholeModelFeeObserverHandle;
	}

protected:
	LLRootHandle<LLWholeModelFeeObserver> mWholeModelFeeObserverHandle;
};


class LLWholeModelUploadObserver
{
public:
	LLWholeModelUploadObserver() { mWholeModelUploadObserverHandle.bind(this); }
	virtual ~LLWholeModelUploadObserver() {}

	virtual void onModelUploadSuccess() = 0;

	virtual void onModelUploadFailure() = 0;

	LLHandle<LLWholeModelUploadObserver> getWholeModelUploadObserverHandle() const
	{
		return mWholeModelUploadObserverHandle;
	}

protected:
	LLRootHandle<LLWholeModelUploadObserver> mWholeModelUploadObserverHandle;
};


class LLUploadModelPremissionsResponder : public LLHTTPClient::Responder
{
public:

	LLUploadModelPremissionsResponder(const LLHandle<LLUploadPermissionsObserver>& observer);

	void error(U32 status, const std::string& reason);

	void result(const LLSD& content);

private:
	LLHandle<LLUploadPermissionsObserver> mObserverHandle;
};

#endif /* LL_LLUPLOADFLOATEROBSERVERS_H */

==> SingularityViewer-1.8.3.tar.gz: SingularityViewer-1.8.3/indra/newview/lluploadfloaterobservers.h <==
/**
 * @file lluploadfloaterobservers.h
 * @brief LLUploadModelPremissionsResponder declaration
 *
 * $LicenseInfo:firstyear=2011&license=viewergpl$
 * 
 * Copyright (c) 2011, Linden Research, Inc.
 * 
 * Second Life Viewer Source Code
 * The source code in this file ("Source Code") is provided by Linden Lab
 * to you under the terms of the GNU General Public License, version 2.0
 * ("GPL"), unless you have obtained a separate licensing agreement
 * ("Other License"), formally executed by you and Linden Lab.  Terms of
 * the GPL can be found in doc/GPL-license.txt in this distribution, or
 * online at http://secondlifegrid.net/programs/open_source/licensing/gplv2
 * 
 * There are special exceptions to the terms and conditions of the GPL as
 * it is applied to this Source Code. View the full text of the exception
 * in the file doc/FLOSS-exception.txt in this software distribution, or
 * online at
 * http://secondlifegrid.net/programs/open_source/licensing/flossexception
 * 
 * By copying, modifying or distributing this software, you acknowledge
 * that you have read and understood your obligations described above,
 * and agree to abide by those obligations.
 * 
 * ALL LINDEN LAB SOURCE CODE IS PROVIDED "AS IS." LINDEN LAB MAKES NO
 * WARRANTIES, EXPRESS, IMPLIED OR OTHERWISE, REGARDING ITS ACCURACY,
 * COMPLETENESS OR PERFORMANCE.
 * $/LicenseInfo$
 */

#ifndef LL_LLUPLOADFLOATEROBSERVERS_H
#define LL_LLUPLOADFLOATEROBSERVERS_H

#include "llfloater.h"
#include "llhttpclient.h"
#include "llui.h"

class AIHTTPTimeoutPolicy;
extern AIHTTPTimeoutPolicy uploadModelPremissionsResponder_timeout;

class LLUploadPermissionsObserver
{
public:

	LLUploadPermissionsObserver() { mUploadPermObserverHandle.bind(this); }
	virtual ~LLUploadPermissionsObserver() {}

	virtual void onPermissionsReceived(const LLSD& result) = 0;
	virtual void setPermissonsErrorStatus(U32 status, const std::string& reason) = 0;

	LLHandle<LLUploadPermissionsObserver> getPermObserverHandle() const
	{
		return mUploadPermObserverHandle;
	}

protected:
	LLRootHandle<LLUploadPermissionsObserver> mUploadPermObserverHandle;
};

class LLWholeModelFeeObserver
{
public:
	LLWholeModelFeeObserver() { mWholeModelFeeObserverHandle.bind(this); }
	virtual ~LLWholeModelFeeObserver() {}

	virtual void onModelPhysicsFeeReceived(const LLSD& result, std::string upload_url) = 0;
	virtual void setModelPhysicsFeeErrorStatus(U32 status, const std::string& reason) = 0;

	LLHandle<LLWholeModelFeeObserver> getWholeModelFeeObserverHandle() const
	{
		return mWholeModelFeeObserverHandle;
	}

protected:
	LLRootHandle<LLWholeModelFeeObserver> mWholeModelFeeObserverHandle;
};


class LLWholeModelUploadObserver
{
public:
	LLWholeModelUploadObserver() { mWholeModelUploadObserverHandle.bind(this); }
	virtual ~LLWholeModelUploadObserver() {}

	virtual void onModelUploadSuccess() = 0;

	virtual void onModelUploadFailure() = 0;

	LLHandle<LLWholeModelUploadObserver> getWholeModelUploadObserverHandle() const
	{
		return mWholeModelUploadObserverHandle;
	}

protected:
	LLRootHandle<LLWholeModelUploadObserver> mWholeModelUploadObserverHandle;
};


class LLUploadModelPremissionsResponder : public LLHTTPClient::ResponderWithResult
{
public:

	LLUploadModelPremissionsResponder(const LLHandle<LLUploadPermissionsObserver>& observer);

	/*virtual*/ void error(U32 status, const std::string& reason);
	/*virtual*/ void result(const LLSD& content);
	/*virtual*/ AIHTTPTimeoutPolicy const& getHTTPTimeoutPolicy(void) const { return uploadModelPremissionsResponder_timeout; }
	/*virtual*/ char const* getName(void) const { return "LLUploadModelPremissionsResponder"; }

private:
	LLHandle<LLUploadPermissionsObserver> mObserverHandle;
};

#endif /* LL_LLUPLOADFLOATEROBSERVERS_H */
